@@ -16,6 +16,9 @@ Implementation Notes
 
 **Hardware:**
 
+* `Adafruit's ADT7410 analog temperature Sensor Breakout:
+  <https://www.adafruit.com/product/4089>`_ (Product ID: 4089)
+
 **Software and Dependencies:**
 
 * Adafruit CircuitPython firmware for the supported boards:
@@ -46,7 +49,35 @@ _ADT7410_SWRST = const(0x2F)
 
 
 class ADT7410:
-    """Interface to the Analog Devices ADT7410 temperature sensor."""
+    """Interface to the Analog Devices ADT7410 temperature sensor.
+
+    :param ~busio.I2C i2c_bus: The I2C bus the ADT7410 is connected to.
+    :param int address: The I2C device address. Default is :const:`0x48`
+
+    **Quickstart: Importing and using the ADT7410 temperature sensor**
+
+        Here is an example of using the :class:`ADT7410` class.
+        First you will need to import the libraries to use the sensor
+
+        .. code-block:: python
+
+            import board
+            import adafruit_adt7410
+
+        Once this is done you can define your `board.I2C` object and define your sensor object
+
+        .. code-block:: python
+
+            i2c = board.I2C()  # uses board.SCL and board.SDA
+            adt = adafruit_adt7410.ADT7410(i2c_bus, address=0x48)
+
+        Now you have access to the temperature using :attr:`temperature`.
+
+        .. code-block:: python
+
+            temperature = adt.temperature
+
+    """
 
     # many modes can be set with register objects for simplicity
     ready = ROBit(_ADT7410_STATUS, 7)
@@ -69,7 +100,7 @@ class ADT7410:
 
     @property
     def temperature(self):
-        """The temperature in celsius"""
+        """The temperature in Celsius"""
         temp = self._read_register(_ADT7410_TEMPMSB, 2)
         return struct.unpack(">h", temp)[0] / 128
 
